==> 0.0.2.tar.gz: lib/src/services/share.dart <==
import 'dart:async';

import 'package:ocg_share/src/models/share_data.dart';
import 'package:rxdart/rxdart.dart';
import 'package:receive_sharing_intent/receive_sharing_intent.dart';
import 'package:share/share.dart';

abstract class ShareService {
  Future<void> share(ShareData data);
  Future<List<ShareData>> receiveIntent();
  Stream<ShareData> receiveIntentStream();
}

class ShareServiceImpl extends ShareService {
  BehaviorSubject<ShareData> _subject;
  StreamSubscription _textSubscription;
  StreamSubscription _fileSubscription;

  ShareServiceImpl();
  @override
  Stream<ShareData> receiveIntentStream() {
    if (_subject == null) {
      this._subject = BehaviorSubject<ShareData>();
    }
    if (_textSubscription == null) {
      _textSubscription =
          ReceiveSharingIntent.getTextStream().listen((String value) {
        _subject.add(ShareData.named(content: value, type: MimeType.textPlain));
      });
    }
    if (_fileSubscription == null) {
      // TODO add support for multiple files
      _fileSubscription = ReceiveSharingIntent.getMediaStream()
          .listen((List<SharedMediaFile> files) {
        _subject.add(ShareData.named(
            content: files[0], type: types[files[0].type.index]));
      });
    }
    return _subject.stream;
  }

  @override
  Future<List<ShareData>> receiveIntent() async {
    List<ShareData> data = [];
    String text = await ReceiveSharingIntent.getInitialText();
    List<SharedMediaFile> sharedMediaFile =
        await ReceiveSharingIntent.getInitialMedia();
    if (text != null) {
      data.add(ShareData.named(content: text, type: MimeType.textPlain));
    }
    if (sharedMediaFile != null) {
      sharedMediaFile.forEach((element) {
        data.add(ShareData.named(
            content: element.path, type: types[element.type.index]));
      });
    }
    return data;
  }

  List<String> get types =>
      [MimeType.image(), MimeType.video(), MimeType.audio()];

  @override
  Future<void> share(ShareData data) async {
    if (data.type == MimeType.textPlain) {
      await Share.share(data.content);
      return;
    }
    await Share.shareFiles([data.content], mimeTypes: [data.type]);
  }

  void closeIntent() {
    if (_subject.isBroadcast) {
      _subject?.close();
      _subject = null;
      _textSubscription.cancel();
      _textSubscription = null;
      _fileSubscription.cancel();
      _fileSubscription = null;
    }
  }
}

==> 0.0.3.tar.gz: lib/src/services/share.dart <==
import 'dart:async';

import 'package:ocg_share/src/models/share_data.dart';
import 'package:rxdart/rxdart.dart';
import 'package:receive_sharing_intent/receive_sharing_intent.dart';
import 'package:share/share.dart';

abstract class ShareService {
  Future<void> share(ShareData data);
  Future<ShareData> receiveIntent();
  Stream<ShareData> receiveIntentStream();
  Future<void> close();
}

class ShareServiceImpl extends ShareService {
  BehaviorSubject<ShareData> _subject;
  StreamSubscription _textSubscription;
  StreamSubscription _fileSubscription;

  ShareServiceImpl();
  @override
  Stream<ShareData> receiveIntentStream() {
    if (_subject == null) {
      this._subject = BehaviorSubject<ShareData>();
    }
    if (_textSubscription == null) {
      _textSubscription =
          ReceiveSharingIntent.getTextStream().listen((String value) {
        _subject.add(ShareData.named(content: value, type: MimeType.textPlain));
      });
    }
    if (_fileSubscription == null) {
      // TODO add support for multiple files
      _fileSubscription = ReceiveSharingIntent.getMediaStream()
          .listen((List<SharedMediaFile> files) {
        _subject.add(ShareData.named(
            content: files[0], type: types[files[0].type.index]));
      });
    }
    return _subject.stream;
  }

  @override
  Future<ShareData> receiveIntent() async {
    List<ShareData> data = [];
    String text = await ReceiveSharingIntent.getInitialText();
    List<SharedMediaFile> sharedMediaFile =
        await ReceiveSharingIntent.getInitialMedia();
    if (text != null) {
      return ShareData.named(content: text, type: MimeType.textPlain);
    }
    if (sharedMediaFile != null) {
      return ShareData.named(
          content: sharedMediaFile[0].path,
          type: types[sharedMediaFile[0].type.index]);
    }
    return null;
  }

  List<String> get types =>
      [MimeType.image(), MimeType.video(), MimeType.audio()];

  @override
  Future<void> share(ShareData data) async {
    if (data.type == MimeType.textPlain) {
      await Share.share(data.content);
      return;
    }
    await Share.shareFiles([data.content], mimeTypes: [data.type]);
  }

  @override
  Future<void> close() async {
    if (_subject.isBroadcast) {
      _subject?.close();
      _subject = null;
      _textSubscription.cancel();
      _textSubscription = null;
      _fileSubscription.cancel();
      _fileSubscription = null;
    }
  }
}
